@@ -2,10 +2,11 @@
 # HOST_API_V1 = "http://wally113.cit.tu-berlin.de:5444/"
 
 HOST_API_V1 = "https://demo.logsight.ai/api_v1/"
+HOST_API_V1 = "https://logsight.ai/api_v1/"
 PATH_DATA = "/api_v1/data"
 PATH_RESULTS = "/api_v1/results"
 
-HOST_API = "https://demo.logsight.ai/api_v1/"
+HOST_API = "https://logsight.ai/api_v1/"
 PATH_APP_CREATE = "/api/applications/create"
 PATH_APP_LST = "/api/applications/user"
 PATH_APP_DELETE = "/api/applications"
